summaryrefslogtreecommitdiff
path: root/usr
diff options
context:
space:
mode:
authorseb <none@none>2006-07-21 15:05:23 -0700
committerseb <none@none>2006-07-21 15:05:23 -0700
commit945c212afec9d02b63fcd6b175ab711ffb55bf3b (patch)
tree84455202b5a1f7cacba2d2f12d44bc268835897d /usr
parent7f4f06d2ae918f5a65beea8cd5d9192940b9101d (diff)
downloadillumos-gate-945c212afec9d02b63fcd6b175ab711ffb55bf3b.tar.gz
6445821 mac_ether modinfo description should be adjusted
6449604 unused typedef ks_update_fnp in mac_stat.c 6449620 superfluous ARGSUSED in front of mac_register() 6449650 mac_interface_stat enum has aesthetic problems
Diffstat (limited to 'usr')
-rw-r--r--usr/src/uts/common/io/mac/mac.c1
-rw-r--r--usr/src/uts/common/io/mac/mac_stat.c2
-rw-r--r--usr/src/uts/common/io/mac/plugins/mac_ether.c4
-rw-r--r--usr/src/uts/common/sys/mac_impl.h9
4 files changed, 5 insertions, 11 deletions
diff --git a/usr/src/uts/common/io/mac/mac.c b/usr/src/uts/common/io/mac/mac.c
index 6e2ea66bb0..80d3583fbd 100644
--- a/usr/src/uts/common/io/mac/mac.c
+++ b/usr/src/uts/common/io/mac/mac.c
@@ -1034,7 +1034,6 @@ mac_free(mac_register_t *mregp)
* opaque pointer becomes the driver's handle to its MAC interface, and is
* the argument to all other mac module entry points.
*/
-/* ARGSUSED */
int
mac_register(mac_register_t *mregp, mac_handle_t *mhp)
{
diff --git a/usr/src/uts/common/io/mac/mac_stat.c b/usr/src/uts/common/io/mac/mac_stat.c
index 85d716c1ef..4b48ac5763 100644
--- a/usr/src/uts/common/io/mac/mac_stat.c
+++ b/usr/src/uts/common/io/mac/mac_stat.c
@@ -39,8 +39,6 @@
#define MAC_KSTAT_NAME "mac"
#define MAC_KSTAT_CLASS "net"
-typedef int (*ks_update_fnp)(struct kstat *, int);
-
static mac_stat_info_t i_mac_si[] = {
{ MAC_STAT_IFSPEED, "ifspeed", KSTAT_DATA_UINT64, 0 },
{ MAC_STAT_MULTIRCV, "multircv", KSTAT_DATA_UINT32, 0 },
diff --git a/usr/src/uts/common/sys/mac_impl.h b/usr/src/uts/common/sys/mac_impl.h
index 9bf6b21d60..bc4bea80de 100644
--- a/usr/src/uts/common/sys/mac_impl.h
+++ b/usr/src/uts/common/sys/mac_impl.h
@@ -36,15 +36,12 @@ extern "C" {
#endif
/*
- * Statistics of class MAC_INTERFACE_STAT, maintained internally by the mac
- * module.
+ * Statistics maintained internally by the mac module.
*/
-enum mac_interface_stat {
+enum mac_mod_stat {
MAC_STAT_LINK_STATE,
MAC_STAT_LINK_UP,
- MAC_STAT_PROMISC,
-
- MAC_INTERFACE_NSTAT /* Must be the last entry */
+ MAC_STAT_PROMISC
};
typedef struct mac_multicst_addr_s mac_multicst_addr_t;
diff --git a/usr/src/uts/common/io/mac/plugins/mac_ether.c b/usr/src/uts/common/io/mac/plugins/mac_ether.c
index 7636fa996a..62f2f2c6b3 100644
--- a/usr/src/uts/common/io/mac/plugins/mac_ether.c
+++ b/usr/src/uts/common/io/mac/plugins/mac_ether.c
@@ -26,7 +26,7 @@
#pragma ident "%Z%%M% %I% %E% SMI"
/*
* DL_ETHER MAC Type plugin for the Nemo mac module
*/
#include <sys/types.h>
@@ -100,7 +100,7 @@ static mac_stat_info_t ether_stats[] = {
static struct modlmisc mac_ether_modlmisc = {
&mod_miscops,
- "DL_ETHER MAC Type plugin"
+ "Ethernet MAC plugin %I%"
};
static struct modlinkage mac_ether_modlinkage = {
@@ -26,7 +26,7 @@
#pragma ident "%Z%%M% %I% %E% SMI"
/*
- * DL_ETHER MAC Type plugin for the Nemo mac module
+ * Ethernet MAC plugin for the Nemo mac module
*/
#include <sys/types.h>